@@ -22,6 +22,10 @@ sub call {
         my $message;
         my $msgId;
         my $senderType;
+        my $isAt = 0;
+        if($msg->is_at) {
+        $isAt=1;
+        }
         if($msg->type eq 'friend_message'){
             return if $data->{is_ban_official} and $msg->sender->category eq '公众号';
             $msgId = $msg->sender->id;
@@ -30,8 +34,10 @@ sub call {
             $senderType = '1';
         }
         elsif($msg->type eq 'group_message'){
+        if(!$isAt)  {
             return if ref $data->{ban_group}  eq "ARRAY" and @{$data->{ban_group}} and first {$_=~/^\d+$/?$msg->group->uid eq $_:$msg->group->displayname eq $_} @{$data->{ban_group}};
             return if ref $data->{allow_group}  eq "ARRAY" and @{$data->{allow_group}} and !first {$_=~/^\d+$/?$msg->group->uid eq $_:$msg->group->displayname eq $_} @{$data->{allow_group}};
+            }
             $msgId = $msg->group->id;
             $title = $msg->group->displayname;
             $message = $msg->sender->displayname . ": " . $msg->content;
@@ -39,12 +45,12 @@ sub call {
         }
         return if !$title or !$message;
         $client->http_post($api_url, 
-            {'Authorization'=>"key=$api_key",},
+            {'Authorization'=>"key=$api_key",json=>1},
             json=>{
                 registration_ids=> $registration_ids,
                 $collapse_key?(collapse_key=> $collapse_key):(),
                 priority=> $data->{priority} // 'high',
-                data=>{type=>$type,title=>$title,message=>$message,msgId=>$msgId,senderType=>$senderType},
+                data=>{isAt=>$isAt,type=>$type,title=>$title,message=>$message,msgId=>$msgId,senderType=>$senderType},
             },
             sub{
                 #"{"multicast_id":9016211065189210367,"success":1,"failure":0,"canonical_ids":0,"results":[{"message_id":"0:1484103730761325%9b9e6c13f9fd7ecd"}]}"
@@ -81,6 +87,7 @@ sub call {
         else{return}
         $client->http_post($api_url,
             {   'Authorization'=>"key=$api_key",
+                json=>1,
                 blocking=>1,
                 ua_connect_timeout=>5,
                 ua_request_timeout=>5,
